==> huaweicloudsdkiam-3.1.141-py2.py3-none-any.whl: huaweicloudsdkiam/v5/model/update_access_key_v5_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAccessKeyV5Response(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'access_key': 'AccessKeyMetadata'
    }

    attribute_map = {
        'access_key': 'access_key'
    }

    def __init__(self, access_key=None):
        """UpdateAccessKeyV5Response

        The model defined in huaweicloud sdk

        :param access_key: 
        :type access_key: :class:`huaweicloudsdkiam.v5.AccessKeyMetadata`
        """
        
        super(UpdateAccessKeyV5Response, self).__init__()

        self._access_key = None
        self.discriminator = None

        if access_key is not None:
            self.access_key = access_key

    @property
    def access_key(self):
        """Gets the access_key of this UpdateAccessKeyV5Response.

        :return: The access_key of this UpdateAccessKeyV5Response.
        :rtype: :class:`huaweicloudsdkiam.v5.AccessKeyMetadata`
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        """Sets the access_key of this UpdateAccessKeyV5Response.

        :param access_key: The access_key of this UpdateAccessKeyV5Response.
        :type access_key: :class:`huaweicloudsdkiam.v5.AccessKeyMetadata`
        """
        self._access_key = access_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAccessKeyV5Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.1.151-py2.py3-none-any.whl: huaweicloudsdkiam/v5/model/update_access_key_v5_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAccessKeyV5Response(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'access_key': 'AccessKeyMetadata'
    }

    attribute_map = {
        'access_key': 'access_key'
    }

    def __init__(self, access_key=None):
        r"""UpdateAccessKeyV5Response

        The model defined in huaweicloud sdk

        :param access_key: 
        :type access_key: :class:`huaweicloudsdkiam.v5.AccessKeyMetadata`
        """
        
        super(UpdateAccessKeyV5Response, self).__init__()

        self._access_key = None
        self.discriminator = None

        if access_key is not None:
            self.access_key = access_key

    @property
    def access_key(self):
        r"""Gets the access_key of this UpdateAccessKeyV5Response.

        :return: The access_key of this UpdateAccessKeyV5Response.
        :rtype: :class:`huaweicloudsdkiam.v5.AccessKeyMetadata`
        """
        return self._access_key

    @access_key.setter
    def access_key(self, access_key):
        r"""Sets the access_key of this UpdateAccessKeyV5Response.

        :param access_key: The access_key of this UpdateAccessKeyV5Response.
        :type access_key: :class:`huaweicloudsdkiam.v5.AccessKeyMetadata`
        """
        self._access_key = access_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAccessKeyV5Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
